==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/NativeUIContent.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIContent = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIContent, _super);
    function NativeUIContent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIContent.prototype.get_c = function () {
        return 0;
    };
    Object.defineProperty(NativeUIContent.prototype, "av", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIContent.prototype, "aw", {
        get: function () {
            return this.av.getContent(this.u);
        },
        set: function (a) {
            this.av.setContent(this.u, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUIContent.$t = markType(NativeUIContent, 'NativeUIContent', NativeUIContainer.$);
    return NativeUIContent;
}(NativeUIContainer));
export { NativeUIContent };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/NativeUIContent.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIContent = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIContent, _super);
    function NativeUIContent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIContent.prototype.get_c = function () {
        return 0;
    };
    Object.defineProperty(NativeUIContent.prototype, "az", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIContent.prototype, "a0", {
        get: function () {
            return this.az.getContent(this.u);
        },
        set: function (a) {
            this.az.setContent(this.u, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUIContent.$t = markType(NativeUIContent, 'NativeUIContent', NativeUIContainer.$);
    return NativeUIContent;
}(NativeUIContainer));
export { NativeUIContent };
